==> apache-camel-3.6.0-src.zip: apache-camel-3.6.0/core/camel-api/src/main/java/org/apache/camel/spi/Configurer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spi;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * An annotation used to mark classes to indicate code capable of configuring its options via a getter/setters that can
 * be called via Camels {@link org.apache.camel.spi.PropertyConfigurer}.
 */
@Retention(RetentionPolicy.RUNTIME)
@Documented
@Target({ ElementType.TYPE })
public @interface Configurer {

    /**
     * Whether to let the Camel compiler plugin to generate java source code for fast configuration.
     */
    boolean generateConfigurer() default true;

}

==> apache-camel-4.0.3-src.zip: apache-camel-4.0.3/core/camel-api/src/main/java/org/apache/camel/spi/Configurer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spi;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * An annotation used to mark classes to indicate code capable of configuring its options via a getter/setters that can
 * be called via Camels {@link org.apache.camel.spi.PropertyConfigurer}.
 */
@Retention(RetentionPolicy.RUNTIME)
@Documented
@Target({ ElementType.TYPE })
public @interface Configurer {

    /**
     * Whether to let the Camel compiler plugin to generate java source code for fast configuration.
     */
    boolean generateConfigurer() default true;

    /**
     * Whether this configurer should include extended configurer methods. For example API based components would
     * require this.
     */
    boolean extended() default false;

    /**
     * Whether this configurer is only used during bootstrap
     */
    boolean bootstrap() default false;

}
